#!/bin/python3

import numpy as np
import argparse

from icecube.icetray import I3Units

import matplotlib
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec
from matplotlib.ticker import MultipleLocator

plt.rcParams["font.family"] = "serif"
plt.rcParams["mathtext.fontset"] = "dejavuserif"

parser = argparse.ArgumentParser()
parser.add_argument("input", type=str, help="Input data files.")
args = parser.parse_args()


file = open(args.input, "r")
file.readline()

eng = []
eLow = []
eHigh = []
flux = []
lowStat = []
highStat = []
lowSys = []
highSys = []

nativeFlux = 1 / (I3Units.km2 * I3Units.julianyear * I3Units.eV * I3Units.steradian)
requested = 1 / (I3Units.m2 * I3Units.second * I3Units.steradian * I3Units.GeV)

for line in file:
    cols = [float(val) for val in line.split()]
    eng.append(10 ** cols[0] * I3Units.eV)
    eLow.append(10 ** (cols[0] - cols[1]) * I3Units.eV)
    eHigh.append(10 ** (cols[0] + cols[1]) * I3Units.eV)
    flux.append(cols[3] * nativeFlux)
    lowStat.append(-1 * cols[4] * nativeFlux)
    highStat.append(cols[5] * nativeFlux)
    lowSys.append(-1 * cols[6] * nativeFlux)
    highSys.append(cols[7] * nativeFlux)

for i in range(len(eng)):
    print(
        "{} {} {} {} {} {} {} {}".format(
            eng[i] / I3Units.GeV,
            eLow[i] / I3Units.GeV,
            eHigh[i] / I3Units.GeV,
            flux[i] / requested,
            lowStat[i] / requested,
            highStat[i] / requested,
            lowSys[i] / requested,
            highSys[i] / requested,
        )
    )


fig = plt.figure(figsize=(11, 8))
gs = gridspec.GridSpec(1, 1, wspace=0.2, hspace=0.25)
ax = fig.add_subplot(gs[0])

yerr = np.array([(-low, high) for low, high in zip(lowStat, highStat)])

eng = np.array(eng) / I3Units.eV

ax.errorbar(np.log10(eng), np.array(flux) / nativeFlux * eng ** 2.6, yerr.transpose() / nativeFlux * eng ** 2.6)

ax.set_yscale("log")
ax.set_xscale("log")

plt.show()
